@@ -10,13 +10,13 @@
 namespace Quotient {
 //! Used by clients to determine the homeserver, identity server, and other
 //! optional components they should be interacting with.
-struct DiscoveryInformation {
+struct QUOTIENT_API DiscoveryInformation {
     HomeserverInformation homeserver;
 
-    Omittable<IdentityServerInformation> identityServer{};
+    std::optional<IdentityServerInformation> identityServer{};
 
     //! Application-dependent keys using Java package naming convention.
-    QHash<QString, QJsonObject> additionalProperties{};
+    QVariantHash additionalProperties{};
 };
 
 template <>
@@ -24,13 +24,13 @@ struct JsonObjectConverter<DiscoveryInformation> {
     static void dumpTo(QJsonObject& jo, const DiscoveryInformation& pod)
     {
         fillJson(jo, pod.additionalProperties);
-        addParam<>(jo, QStringLiteral("m.homeserver"), pod.homeserver);
-        addParam<IfNotEmpty>(jo, QStringLiteral("m.identity_server"), pod.identityServer);
+        addParam(jo, "m.homeserver"_L1, pod.homeserver);
+        addParam<IfNotEmpty>(jo, "m.identity_server"_L1, pod.identityServer);
     }
     static void fillFrom(QJsonObject jo, DiscoveryInformation& pod)
     {
-        fillFromJson(jo.take("m.homeserver"_ls), pod.homeserver);
-        fillFromJson(jo.take("m.identity_server"_ls), pod.identityServer);
+        fillFromJson(jo.take("m.homeserver"_L1), pod.homeserver);
+        fillFromJson(jo.take("m.identity_server"_L1), pod.identityServer);
         fromJson(jo, pod.additionalProperties);
     }
 };
