@@ -324,6 +324,13 @@ public:
     //! Get a list of all member Matrix IDs known to the room.
     QStringList memberIds() const;
 
+    //! \brief Get Matrix IDs for room creator(s)
+    //!
+    //! As long as the create event for the room is known, the returned list will start with
+    //! MXID of the room creation event sender. For room versions 12 and newer, the returned list
+    //! will further include additional creators if there are any.
+    QStringList creatorIds() const;
+
     //! Whether the name for the given member should be disambiguated
     bool needsDisambiguation(const QString& userId) const;
 
@@ -691,13 +698,14 @@ public:
     //! \note This is a generic method that only gets the power level to send events with a given
     //!       type. Some operations have additional restrictions or enablers though: e.g.,
     //!       room member changes (kicks, invites) have special power levels; on the other hand,
-    //!       redactions of one's own messages are allowed regardless of the power level. To check
-    //!       effective ability to perform an operation, use Room's can*() methods instead of
-    //!       comparing the power levels (those are also slightly more efficient).
+    //!       redactions of one's own messages are allowed regardless of the power level.
+    //!       The library has no method to check effective ability to perform an operation as yet;
+    //!       you have to either blindly make a call to the homeserver or implement the logic
+    //!       described in the Federation API and respective room versions, in the client code.
     //! \note Unlike the template version below, this method determines at runtime whether an event
     //!       type is that of a state event, assuming unknown event types to be non-state; pass
     //!       `true` as the second parameter to override that.
-    //! \sa canSend, canRedact, canSwitchVersions
+    //! \sa canSwitchVersions
     Q_INVOKABLE int powerLevelFor(const QString& eventTypeId, bool forceStateEvent = false) const;
 
     //! \brief Get the power level required to send events of the given type
@@ -726,8 +734,31 @@ public:
         return post(makeEvent<EvT>(std::forward<ArgTs>(args)...));
     }
 
+    //! \brief Send a text type message
+    //!
+    //! This means MessageEventType Text, Emote or Notice.
+    template<MessageEventType type = MessageEventType::Text>
+    QString postText(const QString& plainText,
+                     const std::optional<QString>& html = std::nullopt,
+                     const std::optional<EventRelation>& relatesTo = std::nullopt)
+    {
+        static_assert(type == MessageEventType::Text || type == MessageEventType::Emote
+                          || type == MessageEventType::Notice,
+                      "MessageEvent type is not a text message");
+
+        return post<RoomMessageEvent>(
+                   plainText, type,
+                   html ? std::make_unique<EventContent::TextContent>(*html, u"text/html"_s)
+                        : nullptr,
+                   relatesTo)
+            ->transactionId();
+    }
+
     QString postFile(const QString& plainText,
                      std::unique_ptr<EventContent::FileContentBase> fileContent);
+    QString postFile(const QString& plainText,
+                     std::unique_ptr<EventContent::FileContentBase> fileContent,
+                     std::optional<EventRelation> relatesTo);
 
     PendingEventItem::future_type whenMessageMerged(QString txnId) const;
 
@@ -750,15 +781,30 @@ public:
 
     QJsonArray exportMegolmSessions();
 
+    //! \brief Upgrade the room to \p newVersion
+    //!
+    //! Triggers an upgrade process that puts the tombstone event on the current room and creates
+    //! a new room of the specified version. It is possible to specify \p additionalCreators for
+    //! room versions that support those (unfortunately it is only possible to find out whether
+    //! a given room version supports additional creators by attempting to upgrade a room).
+    //! \return a future eventually holding a new room once it arrives via sync
+    QFuture<Expected<Room*, BaseJob::Status>> upgrade(QString newVersion,
+                                                      const QStringList& additionalCreators = {});
+
 public Q_SLOTS:
     /** Check whether the room should be upgraded */
     void checkVersion();
 
+    [[deprecated("Use postText() instead")]]
     QString postMessage(const QString& plainText, MessageEventType type);
+    [[deprecated("Use postText() instead")]]
     QString postPlainText(const QString& plainText);
+    [[deprecated("Use postText() instead")]]
     QString postHtmlMessage(const QString& plainText, const QString& html,
                             MessageEventType type = MessageEventType::Text);
+    [[deprecated("Use postText() instead")]]
     QString postHtmlText(const QString& plainText, const QString& html);
+
     /// Send a reaction on a given event with a given key
     QString postReaction(const QString& eventId, const QString& key);
 
@@ -811,7 +857,7 @@ public Q_SLOTS:
     //! Put the fully-read marker at the latest message in the room
     void markAllMessagesAsRead();
 
-    /// Switch the room's version (aka upgrade)
+    //! Switch the room's version (aka upgrade)
     void switchVersion(QString newVersion);
 
     void inviteCall(const QString& callId, const int lifetime,
@@ -870,6 +916,9 @@ Q_SIGNALS:
      */
     void messageSent(QString txnId, QString eventId);
 
+    //! A new thread has been created/added in the room
+    void newThread(const Thread& newThread);
+
     /** A common signal for various kinds of changes in the room
      * Aside from all changes in the room state
      * @param changes a set of flags describing what changes occurred
